import 'package:cs_resources/generated/l10n.dart';
import 'package:domain/entity/latest_news_page_entity.dart';
import 'package:domain/repository/main_repository.dart';
import 'package:flutter/material.dart';
import 'package:plugin_basic/modules/global_web_page.dart';
import 'package:plugin_platform/engine/toast/toast_engine.dart';
import 'package:plugin_platform/http/dio/dio_cancelable_mixin.dart';
import 'package:riverpod_annotation/riverpod_annotation.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/widget_export.dart';

import 'latest_news_info_state.dart';

part 'latest_news_info_view_model.g.dart';

@riverpod
class LatestNewsInfoViewModel extends _$LatestNewsInfoViewModel with DioCancelableMixin{
  late final MainRepository _mainRepository;
  var _curPage = 1; //请求参数当前的页面
  var _needShowPlaceholder = true; //是否展示LoadingView

  // Refresh 控制器
  final EasyRefreshController refreshController = EasyRefreshController(
    controlFinishRefresh: true, //允许刷新
    controlFinishLoad: true, //允许加载
  );

  @override
  LatestNewsInfoState build() {
    _mainRepository = ref.read(mainRepositoryProvider);
    final state = LatestNewsInfoState(datas: []);
    registerCancellation();
    return state;
  }

  //刷新页面状态
  void changeLoadingState(LoadState loadState, String? errorMsg) {
    state = state.copyWith(loadingState: loadState, errorMessage: errorMsg);
  }

  // Refresh 刷新事件
  Future onRefresh() async {
    _curPage = 1;
    fetchList();
  }

  // Refresh 加载事件
  Future loadMore() async {
    _curPage++;
    fetchList();
  }

  // 重试请求
  Future retryRequest() async {
    _curPage = 1;
    _needShowPlaceholder = true;
    fetchList();
  }

  /// 获取服务器数据
  Future fetchList() async {
    if (_needShowPlaceholder) {
      changeLoadingState(LoadState.State_Loading, null);
    }

    // 获取列表
    var listResult = await _mainRepository.fetchLatestNewsList(
      type: "3",
      curPage: _curPage,
      cancelToken: cancelToken,
    );

    // 处理数据
    if (listResult.isSuccess) {
      handleList(listResult.data?.list);
    } else {
      changeLoadingState(LoadState.State_Error, listResult.errorMsg);
    }

    // 最后赋值
    _needShowPlaceholder = false;
  }

// 处理数据与展示的逻辑
  void handleList(List<LatestNewsList>? list) {
    if (list != null && list.isNotEmpty) {
      //有数据，判断是刷新还是加载更多的数据
      if (_curPage == 1) {
        //刷新的方式
        state = state.copyWith(datas: list);
        refreshController.finishRefresh();

        //更新展示的状态
        changeLoadingState(LoadState.State_Success, null);
      } else {
        //加载更多
        state.datas.addAll(List<LatestNewsList>.from(state.datas)..addAll(list));
        refreshController.finishLoad();
      }
    } else {
      if (_curPage == 1) {
        //展示无数据的布局
        state = state.copyWith(datas: []);
        changeLoadingState(LoadState.State_Empty, null);
        refreshController.finishRefresh();
      } else {
        //展示加载完成，没有更多数据了
        refreshController.finishLoad(IndicatorResult.noMore);
      }
    }
  }

  /// 去详情页面
  void gotoLatestNewsDetail(BuildContext context, LatestNewsList data) async {
    final result = await _mainRepository.fetchLatestNewsDetail(id: data.id ?? "");
    if (result.isSuccess) {
      GlobalWebPage.startInstance(context: context, title: S.current.latest_news, url: result.data?.content ?? "");
    } else {
      ToastEngine.show(result.errorMsg ?? "Network Load Error");
    }
  }

}
